import subprocess
from sqlalchemy import create_engine, text, inspect
from src.config import DATABASE_URI
import sys
import os
sys.path.append(os.path.join(os.path.dirname(__file__), 'src'))

engine = create_engine(DATABASE_URI)

def drop_database():
    confirm = input("This will drop the entire database. Are you sure? (y/n): ")
    if confirm.lower() == 'y':
        subprocess.run(['python', 'Activity1/src/drop_database.py'], check=True)
        print("Database cleared.")
    else:
        print("Operation canceled.")

def setup_database():
    subprocess.run(['python', 'Activity1/src/database_setup.py'], check=True)
    print("Database setup completed.")

def import_data():
    subprocess.run(['python', 'Activity1/src/data_import.py'], check=True)
    print("Data import completed.")

def run_queries():
    if not check_database_setup():
        print("Database is not set up. Please run setup first.")
        return
    subprocess.run(['python', 'Activity1/src/queries.py'], check=True)

def check_database_setup():
    return check_tables_exist()

def check_tables_exist():
    """Check if the expected tables exist in the database."""
    inspector = inspect(engine)
    tables = inspector.get_table_names()
    expected_tables = {'players', 'teams', 'contracts'}
    return expected_tables.issubset(set(tables))

def check_data_imported():
    """Check if the 'players' table (or another representative table) has data."""
    with engine.connect() as conn:
        result = conn.execute(text("SELECT COUNT(*) FROM players"))
        count = result.scalar()
    return count > 0

def main():
    actions = {
        '1': drop_database,
        '2': setup_database,
        '3': import_data,
        '4': run_queries,
    }
    
    while True:
        print("\nAvailable commands:")
        print("1 - Drop database")
        print("2 - Setup database")
        print("3 - Import data")
        print("4 - Run queries")
        print("b - Back")  # Changed from 'q - Quit' to 'b - Back'
        
        choice = input("Enter your choice: ")
        if choice == 'b':
            return  

        if choice == '2' and check_tables_exist():
            print("Database already set up. Please drop the database first if you want to reset.")
            continue

        if choice == '3' and not check_tables_exist():
            print("Database is not set up. Please run setup first.")
            continue

        if choice == '3' and check_data_imported():
            print("Data already imported. Please drop and setup the database again if you want to re-import.")
            continue

        if choice == '4' and not check_tables_exist():
            print("Database is not set up. Please run setup first.")
            continue

        if choice == '4' and not check_data_imported():
            print("No data to query. Please import data first.")
            continue

        action = actions.get(choice)
        if action:
            action()
        else:
            print("Invalid choice.")

if __name__ == "__main__":
    main()