from sqlalchemy.orm import sessionmaker
from sqlalchemy.exc import SQLAlchemyError
from db import get_engine
from normalisation import read_and_normalise_data
import pandas as pd

engine = get_engine()
Session = sessionmaker(bind=engine)

def import_data(session, players_df, teams_df, contracts_df):
    try:
        with session.begin():
            players_df.to_sql('players', engine, if_exists='append', index=False, method='multi')
            teams_df.to_sql('teams', engine, if_exists='append', index=False, method='multi')
            teams_with_id = pd.read_sql_table('teams', engine)
            players_with_id = pd.read_sql_table('players', engine)
            contracts_df = contracts_df.merge(players_with_id[['id', 'name']], left_on='PLAYER NAME', right_on='name')
            contracts_df = contracts_df.merge(teams_with_id[['id', 'name']], left_on='CURRENT TEAM', right_on='name', suffixes=('_player', '_team'))
            contracts_df.rename(columns={'id_player': 'player_id', 'id_team': 'team_id'}, inplace=True)
            contracts_df.drop(['PLAYER NAME', 'CURRENT TEAM', 'name_player', 'name_team'], axis=1, inplace=True)
            contracts_df.to_sql('contracts', engine, if_exists='append', index=False, method='multi')

    except SQLAlchemyError as e:
        session.rollback()
        print(f"An error occurred: {e}")
    else:
        print("Data imported successfully.")

def main():
    session = Session()

    players_df, teams_df, contracts_df = read_and_normalise_data('data/players_data.csv')

    import_data(session, players_df, teams_df, contracts_df)

if __name__ == "__main__":
    main()
