from sqlalchemy import Column, Integer, String, Date, Float, ForeignKey, UniqueConstraint
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship
from sqlalchemy.schema import Index

Base = declarative_base()

class Player(Base):
    __tablename__ = 'players'
    id = Column(Integer, primary_key=True)
    name = Column(String, nullable=False)
    dob = Column(Date, nullable=False)
    gender = Column(String(1), nullable=False)
    date_signed_up = Column(Date, nullable=False)
    __table_args__ = (
        Index('idx_player_name_dob', 'name', 'dob', unique=True),
        Index('idx_players_gender', 'gender'),
        Index('idx_players_date_signed_up', 'date_signed_up'),
    )


class Team(Base):
    __tablename__ = 'teams'
    id = Column(Integer, primary_key=True)
    name = Column(String, nullable=False)
    location = Column(String, nullable=False)
    manager = Column(String, nullable=False)
    __table_args__ = (UniqueConstraint('name', 'location', 'manager', name='uix_team_name_location_manager'),)

class Contract(Base):
    __tablename__ = 'contracts'
    id = Column(Integer, primary_key=True)
    player_id = Column(Integer, ForeignKey('players.id'), nullable=False)
    team_id = Column(Integer, ForeignKey('teams.id'), nullable=False)
    salary_per_week = Column(Float, nullable=False)
    start_date = Column(Date, nullable=False)
    duration_years = Column(Integer, nullable=False)
    commission_percentage = Column(Float, nullable=False)
    
    player = relationship("Player", backref="contracts")
    team = relationship("Team", backref="contracts")
    __table_args__ = (
        Index('idx_contract_player_id', 'player_id'),
        Index('idx_contract_team_id', 'team_id'),
        Index('idx_contracts_start_date', 'start_date'),
    )

