import pandas as pd

def read_and_normalise_data(filepath):
    try:
        df = pd.read_csv(filepath, encoding='windows-1252', engine='python')

        teams_df = df[['CURRENT TEAM', 'TEAM LOCATION', 'TEAM MANAGER']].drop_duplicates().copy()
        teams_df.rename(columns={'CURRENT TEAM': 'name', 'TEAM LOCATION': 'location', 'TEAM MANAGER': 'manager'}, inplace=True)

        players_df = df[['PLAYER NAME', 'DATE OF BIRTH', 'GENDER', 'DATE SIGNED UP']].drop_duplicates(subset=['PLAYER NAME', 'DATE OF BIRTH']).copy()
        players_df.rename(columns={'PLAYER NAME': 'name', 'DATE OF BIRTH': 'dob', 'GENDER': 'gender', 'DATE SIGNED UP': 'date_signed_up'}, inplace=True)

        for date_column in ['dob', 'date_signed_up']:
            players_df[date_column] = pd.to_datetime(players_df[date_column], errors='coerce', dayfirst=True)
            players_df[date_column] = players_df[date_column].dt.strftime('%Y-%m-%d')

        contracts_df = df[['PLAYER NAME', 'CURRENT TEAM', 'SALARY (£k/Week)', 'START OF CONTRACT', 'CONTRACT DURATION', 'COMMISSION (%)']].copy()
        contracts_df.rename(columns={'SALARY (£k/Week)': 'salary_per_week', 'START OF CONTRACT': 'start_date', 'CONTRACT DURATION': 'duration_years', 'COMMISSION (%)': 'commission_percentage'}, inplace=True)
        contracts_df['salary_per_week'] = pd.to_numeric(contracts_df['salary_per_week'], errors='coerce') * 1000

        contracts_df['start_date'] = pd.to_datetime(contracts_df['start_date'], errors='coerce', dayfirst=True)
        contracts_df['start_date'] = contracts_df['start_date'].dt.strftime('%Y-%m-%d')

        contracts_df.fillna(0, inplace=True)

    except Exception as e:
        print(f"An error occurred while reading or normalizing data: {e}")
        return pd.DataFrame(), pd.DataFrame(), pd.DataFrame()

    return players_df, teams_df, contracts_df
