from db import get_engine
from sqlalchemy import text

def list_players_contract_expiring_next_12_months():

    query = text("""
    SELECT p.name
    FROM players p
    JOIN contracts c ON p.id = c.player_id
    WHERE c.start_date + (c.duration_years * INTERVAL '1 year') < (CURRENT_DATE + INTERVAL '1 year')
    AND c.start_date + (c.duration_years * INTERVAL '1 year') > CURRENT_DATE
    """)

    engine = get_engine()   
    with engine.connect() as connection:
        result = connection.execute(query)
        return [row[0] for row in result.fetchall()]


def list_female_players_three_years_service():
    query = text("""
    SELECT p.name
    FROM players p
    JOIN contracts c ON p.id = c.player_id
    WHERE p.gender = 'F'
    AND EXTRACT(year FROM age(CURRENT_DATE, c.start_date)) >= 3
    GROUP BY p.name
    HAVING COUNT(DISTINCT c.team_id) >= 1
    """)

    engine = get_engine()
    with engine.connect() as connection:
        result = connection.execute(query)
        return [row[0] for row in result.fetchall()]

def list_top_5_income_generating_players():
    query = text("""
    SELECT p.name, SUM(c.salary_per_week * 52 * c.duration_years * c.commission_percentage / 100) AS income
    FROM players p
    JOIN contracts c ON p.id = c.player_id
    GROUP BY p.name
    ORDER BY income DESC
    LIMIT 5
    """)

    engine = get_engine()
    with engine.connect() as connection:
        result = connection.execute(query)
        return [row[0] for row in result.fetchall()]

def list_top_5_longest_associated_players():
    query = text("""
    SELECT p.name, MIN(p.date_signed_up) AS signup_date
    FROM players p
    GROUP BY p.name
    ORDER BY signup_date
    LIMIT 5
    """)

    engine = get_engine()
    with engine.connect() as connection:
        result = connection.execute(query)
        return [row[0] for row in result.fetchall()]

def list_players_at_risk_no_contract_renewal():
    query = text("""
    SELECT p.name
    FROM players p
    JOIN contracts c ON p.id = c.player_id
    WHERE c.start_date + (c.duration_years * INTERVAL '1 year') < (CURRENT_DATE + INTERVAL '6 months')
    AND c.start_date + (c.duration_years * INTERVAL '1 year') > CURRENT_DATE
    """)

    engine = get_engine()
    with engine.connect() as connection:
        result = connection.execute(query)
        return [row[0] for row in result.fetchall()]


if __name__ == "__main__":
    print("Players with contracts expiring in the next 12 months:")
    for name in list_players_contract_expiring_next_12_months():
        print(f"Name: {name}")

    print("\nFemale players with at least three years of service with the same team:")
    for name in list_female_players_three_years_service():
        print(f"Name: {name}")

    print("\nTop 5 income-generating players:")
    for name in list_top_5_income_generating_players():
        print(f"Name: {name}")

    print("\nTop 5 longest associated players:")
    for name in list_top_5_longest_associated_players():
        print(f"Name: {name}")

    print("\nPlayers at risk of no contract renewal:")
    for name in list_players_at_risk_no_contract_renewal():
        print(f"Name: {name}")

