import sys
import os
import subprocess
sys.path.append(os.path.join(os.path.dirname(__file__), 'src'))
from src.db import get_database


db = get_database()

def drop_database():
    confirm = input("This will drop the entire database. Are you sure? (y/n): ")
    if confirm.lower() == 'y':
        subprocess.run(['python', 'Activity2/src/drop_database.py'], check=True)
        print("Database cleared.")
    else:
        print("Operation canceled.")

def setup_database():
    if not db.list_collection_names():
        subprocess.run(['python', 'Activity2/src/database_setup.py'], check=True)
        print("Database setup completed.")
    else:
        print("Database already set up. Please drop the database first if you want to reset.")

def import_data():
    if 'players' in db.list_collection_names() and db['players'].count_documents({}) > 0:
        print("Database is not set up. Please run setup first.")
    else:
        subprocess.run(['python', 'Activity2/src/data_import.py'], check=True)
        print("Data import completed.")

def run_queries():
    if 'players' not in db.list_collection_names() or db['players'].count_documents({}) == 0:
        print("No data to query. Please import data first.")
    else:
        subprocess.run(['python', 'Activity2/src/queries.py'], check=True)

def main():
    actions = {
        '1': drop_database,
        '2': setup_database,
        '3': import_data,
        '4': run_queries,
    }
    
    while True:
        print("\nAvailable commands:")
        print("1 - Drop database")
        print("2 - Setup database")
        print("3 - Import data")
        print("4 - Run queries")
        print("b - Back")
        
        choice = input("Enter your choice: ")
        if choice == 'b':
            return

        action = actions.get(choice)
        if action:
            action()
        else:
            print("Invalid choice.")

if __name__ == "__main__":
    main()

