import pandas as pd
from db import get_database
from datetime import datetime
from bson.objectid import ObjectId

def transform_date(date_string):
    try:
        return datetime.strptime(date_string, '%d/%m/%Y')
    except ValueError:
        return None 

def ensure_team(db, document):
    team = db['teams'].find_one({'name': document['name']})
    if team:
        return team['_id']
    else:
        result = db['teams'].insert_one(document)
        return result.inserted_id

def import_data():
    db = get_database()
    players_collection = db['players']
    
    df = pd.read_csv('data/players_data.csv', encoding='windows-1252')
    
    player_documents = []
    for _, row in df.iterrows():
        team_id = ensure_team(db, {
            'name': row['CURRENT TEAM'],
            'location': row['TEAM LOCATION'],
            'manager': row['TEAM MANAGER']
        })
        
        player_document = {
            "_id": ObjectId(),
            "name": row['PLAYER NAME'],
            "dob": transform_date(row['DATE OF BIRTH']),
            "gender": row['GENDER'],
            "date_signed_up": transform_date(row['DATE SIGNED UP']),
            "contracts": [{
                "team_id": team_id,
                "salary_per_week": row['SALARY (£k/Week)'] * 1000,
                "start_date": transform_date(row['START OF CONTRACT']),
                "duration_years": row['CONTRACT DURATION'],
                "commission_percentage": row['COMMISSION (%)']
            }]
        }
        
        player_documents.append(player_document)
    
    if player_documents:
        players_collection.insert_many(player_documents)
    
    print("Data imported successfully.")

if __name__ == "__main__":
    import_data()